================================================================
Οδηγός δημιουργίας διαδραστικού Εργαλείου Εκτίμησης των Κινδύνων
================================================================


1. Εισαγωγή
===========
Ο στόχος σας είναι να δημιουργήσετε το περιεχόμενο του  διαδραστικού εργαλείου Εκτίμησης Κινδύνου (ΕΚ) για επιχειρήσεις που υπάγονται στον τομέα σας, και να τους προσφέρετε αυτό το ειδικό εργαλείο.
Το εργαλείο ΕΚ προάγει μια κλιμακωτή προσέγγιση εκτίμησης κινδύνων και αποτελείται από 5 βήματα:

  * **Προετοιμασία** > ο τομέας εισάγει τους τελικούς χρήστες (επιχειρήσεις) στην αξιολόγηση κινδύνων

  * **Αναγνώριση** > ο τελικός χρήστης εξετάζει τους κινδύνους/προβλήματα και απαντά με ΝΑΙ ή ΟΧΙ
 
  * **Εκτίμηση** > ο τελικός χρήστης εκτιμά τους κινδύνους για κάθε πρόβλημα που εντοπίζει

  * **Σχέδιο δράσης** > ο τελικός χρήστης συμπληρώνει ένα σχέδιο δράσης με μέτρα αντιμετώπισης όλων των αναφερόμενων κινδύνων	

  * **Έκθεση** > το σχέδιο δράσης μετατρέπεται σε μια έκθεση την οποία μπορεί κανείς να κατεβάσει (download) στον υπολογιστή του και να την εκτυπώσει

1.1 Λάβετε υπόψη σας τον τελικό  χρήστη
---------------------------------------

Είναι σημαντικό να **λαμβάνετε υπόψη τον τελικό χρήστη: οι πολύ μικρές και μικρές επιχειρήσεις (εργοδότης και εργαζόμενος(-οι)) και η δομή** του εργαλείου εκτίμησης κινδύνου πρέπει να είναι όσο το δυνατόν πιο κοντά στις καθημερινές δραστηριότητες των επιχειρήσεων. Ο τελικός χρήστης σκέπτεται και δρα με γνώμονα τη δραστηριότητα της επιχείρησής του.
Συχνά, ο τρόπος σκέψης ενός 'ειδικού' διαφέρει από την πρακτική που ακολουθεί ο τελικός χρήστης. Ο τελευταίος σκέπτεται με γνώμονα την επιχειρηματική του δραστηριότητα και μιλά με τη δική του γλώσσα. Ακολουθούν μερικά παραδείγματα:

  * ο 'ειδικός' σκέπτεται περί σωματικού φόρτου εργασίας - *ο τελικός χρήσης σκέπτεται περί σωματικής εργασίας*

  * ο 'ειδικός' σκέπτεται περί θερμοκρασίας του περιβάλλοντος - *ο τελικός χρήσης σκέπτεται περί εργασίας στη ζέστη/στο κρύο*

  * ο 'ειδικός' σκέπτεται περί ασφάλειας και καταρτίζει ένα πακέτο που αφορά τα πάντα σχετικά με αυτό το θέμα - *ο τελικός χρήσης μπορεί να σκεφτεί να ανοίξει ή να κλείσει ένα κατάστημα, για παράδειγμα, και τι ενέχει κάτι τέτοιο, ή τη συναλλαγή με αντιδραστικούς πελάτες και τι πρέπει να κάνει για να τους αντιμετωπίσει.* 

1.2 Χρησιμοποιείτε εύκολη γλώσσα
--------------------------------

**Φροντίστε ώστε η δομή του περιεχομένου του εργαλείου εκτίμησης κινδύνων να συνάδει με τον τρόπο που σκέπτεται και ενεργεί ο μέσος τελικός χρήστης**. Έτσι, το περιεχόμενο γίνεται αναγνωρίσιμο και το σχέδιο δράσης για την αντιμετώπιση των κινδύνων με εφικτά μέτρα εκτελείται πιο εύκολα.
  
Μια άλλη καθοριστική παράμετρος είναι η γλώσσα που θα χρησιμοποιηθεί. Η **γλώσσα** πρέπει να είναι κατανοητή χωρίς να χρειάζεται ερμηνεία, και οι αναφορές στο οτιδήποτε να γίνονται με ονόματα οικεία και συνήθη στις επιχειρήσεις.

Οι σύντομες προτάσεις (το πολύ έως δέκα λέξεις) και η σαφής καθημερινή γλώσσα, που μπορεί να διαβαστεί εύκολα από ανθρώπους βασικού μορφωτικού επιπέδου, συμβάλλουν ώστε ο τελικός χρήστης να το αντιμετωπίσει θετικά και του δίνουν τη δυνατότητα να καταρτίσει μια εκτίμηση και να χρησιμοποιήσει το εργαλείο ΕΚ σωστά.

Στην αρχή του εργαλείου θα έχετε τη δυνατότητα να γράψετε ένα σύντομο εισαγωγικό κείμενο, στέλνοντας έτσι ένα θετικό **και ενθαρρυντικό μήνυμα** σχετικά με:

  * τη **σημασία** της εκτίμησης κινδύνων

  * το γεγονός ότι η εκτίμηση κινδύνων **δεν είναι απαραίτητα πολύπλοκη** (σκοπός είναι να συμβάλλει στην απομυθοποίηση της εκτίμησης κινδύνων)

  * το γεγονός ότι το εργαλείο έχει επινοηθεί ειδικά για να **πληροί τις ανάγκες των επιχειρήσεων** του κλάδου


Είναι σημαντικό το κείμενο να μην είναι πολύ εκτενές, διαφορετικά μπορεί να λειτουργήσει αποτρεπτικά και ο τελικός χρήστης να μη χρησιμοποιήσει το εργαλείο.

2. Ομάδα
========

Παρότι είναι σημαντικό ο αριθμός μελών της ομάδας έργου να παραμείνει σε λογικά επίπεδα, η ομάδα θα πρέπει κατά προτίμηση να αποτελείται από:

  * τον/τους εκπρόσωπος(-ους) επαγγελματικού συλλόγου(-ων)

  * τον/τους εκπρόσωπος(-ους) συλλόγου(-ων) εργαζομένων

  * το σχεδιαστή του διαδραστικού εργαλείου ΕΚ
 
  * έναν ειδικό σε θέματα ασφάλειας και υγείας στην εργασία (με γνώσεις και άμεση σχέση με τον κλάδο)

  * τελικούς χρήστες (π.χ. διοίκηση προσωπικού από εταιρείες, υπαλλήλους συλλόγων εργαζομένων, κ.λπ.)
 

3. Δομή
======= 

3.1 Δομήστε το περιεχόμενο ιεραρχικά
------------------------------------

Πριν αρχίσετε να δημιουργείτε ένα εργαλείο ΕΚ, συνιστούμε να υπολογίσετε τον αριθμό των ζητημάτων που θέλετε να αντιμετωπιστούν. Η ενδελεχής μελέτη της δομής θα αποφέρει καρπούς αργότερα, επομένως ταξινομήστε τα θέματα έτσι, ώστε να είναι σχετικά με τους τελικούς χρήστες. 

Το σύστημα παρέχει τη δυνατότητα ομαδοποίησης των θεμάτων, των επιμέρους θεμάτων και των τύπων κινδύνου μαζί. Ο κύριος στόχος αυτής της ομαδοποίησης είναι η συμπλήρωση του εργαλείου εκτίμησης κινδύνων να γίνει ευκολότερη/πιο εύλογη για τον τελικό χρήστη. Το εργαλείο σας για την εκτίμηση κινδύνων θα πρέπει συνεπώς να αποτελείται από τα εξής:

.. image:: ../images/creation/module.png 
  :align: left
  :height: 32 px
  
**ΕΝΟΤΗΤΕΣ** = θέματα (θέσεις, δραστηριότητες, …)
  
  *Παράδειγμα*: 
    Ενότητα 1: *Σαμπουάν μαλλιών*  (τομέας κομμωτικής)
  
  .. image:: ../images/creation/submodule.png 
    :align: left
    :height: 32 px
    
  **ΕΠΙΜΕΡΟΥΣ ΕΝΟΤΗΤΕΣ** (μη υποχρεωτικές) = επιμέρους θέματα
  
    *Παράδειγμα*: 
      Επιμέρους ενότητα 1: *Στάση του σώματος κατά την εργασία*
      
      Επιμέρους ενότητα 2: *Επαφή με το νερό και τα καλλυντικά προϊόντα*
    
    .. image:: ../images/creation/risk.png 
      :align: left
      :height: 32 px
      
    **ΚΙΝΔΥΝΟΙ** = δηλώσεις για μια κατάσταση η οποία έχει δρομολογηθεί
    
      *Παράδειγμα*: 
        *1.1 Η πολυθρόνα λουσίματος είναι ρυθμιζόμενη*
        
        *2.1 Αγορά κατάλληλων μέσων ατομικής προστασίας, όπως γάντια ασφαλείας μίας χρήσης*
      
      .. image:: ../images/creation/solution.png 
        :align: left
        :height: 32 px
        
      **ΛΥΣΕΙΣ** = προληπτικά μέτρα για την επίλυση του προβλήματος, συνιστώμενα από τον ειδικό
      
        *Παράδειγμα*: 
          *1.1 Συχνά διαλείμματα για ξεκούραση από τη σωματική εργασία*

          *2.1 Χρήση προϊόντων με προστασία από τη σκόνη*


Το σύστημα παρέχει επίσης τη δυνατότητα:

  * να παρακάμψετε μία ενότητα ή μια ολόκληρη ομάδα ενοτήτων σε περίπτωση που το περιεχόμενο δεν συνάδει με τη δραστηριότητα της εταιρείας

  * να επαναλάβετε ορισμένες ενότητες σε περίπτωση επιχειρήσεων που εδρεύουν σε περισσότερα από ένα σημεία.

3.2 Σκεφτείτε τον κίνδυνο ως καταφατική δήλωση
----------------------------------------------

Μόλις αποφασίσετε την κύρια δομή του εργαλείου εκτίμησης κινδύνων, μπορεί να αρχίσετε να αναγνωρίζετε και να επεξηγείτε τους διάφορους κινδύνους.
 
Το σύστημα λειτουργεί με **καταφατικές δηλώσεις**. Δηλαδή, δηλώνει **εάν μια κατάσταση έχει ‘δρομολογηθεί’ (εάν ο στόχος πρόκειται να επιτευχθεί) ή όχι.**
 
 .. note::

   Παράδειγμα: *Υπάρχει καλός φωτισμός.*

Η απάντηση του τελικού χρήστη είναι είτε ένα ξεκάθαρο ‘ναι’ είτε ένα ‘όχι’. Εάν ο τελικός χρήστης απαντήσει ΟΧΙ σημαίνει ότι η κατάσταση δεν έχει δρομολογηθεί), τότε το πρόβλημα συμπεριλαμβάνεται αυτόματα στο αντίστοιχο στάδιο του σχεδίου δράσης και ο τελικός χρήστης θα πρέπει να προτείνει ένα μέτρο αντιμετώπισης του προβλήματος.

3.3 Λάβετε υπόψη τους διαφορετικούς τύπους κινδύνων
---------------------------------------------------

Μπορείτε να επιλέξετε μεταξύ 3 τύπων κινδύνων:

  * έκτακτος κίνδυνος: αφορά σε έναν κίνδυνο που θεωρείται από τον κλάδο ότι συγκαταλέγεται στους υψηλούς κινδύνους. 

    .. note::
    
      Παράδειγμα: *Εργασία σε μεγάλα ύψη στον κλάδο των κατασκευών: το ικρίωμα (σκαλωσιά) είναι τοποθετημένο σε στέρεο έδαφος*


  * κίνδυνος: αφορά σε υπάρχοντες κινδύνους στο χώρο εργασίας ή σχετίζεται με την εργασία που εκτελείται.

    .. note::

      Παράδειγμα: Όλες οι καρέκλες γραφείου είναι ρυθμιζόμενες

Για να αναγνωρίσετε και να εκτιμήσετε τους δύο παραπάνω τύπους κινδύνου, είναι συχνά απαραίτητο να εξετάσετε το χώρο εργασίας (περπατήστε γύρω από το χώρο εργασίας και δείτε τι θα μπορούσε να αποτελέσει κίνδυνο, συμβουλευτείτε τους εργαζόμενους,  …).

 * πολιτική: αφορά σε συμφωνίες, διαδικασίες και διοικητικές αποφάσεις σχετικά με ζητήματα επαγγελματικής ασφάλειας και υγείας. 

    .. note::
    
      Παράδειγμα: Οι κατασκευαστές δέχονται τακτικά ερωτήσεις σχετικά με εναλλακτικά ασφαλή προϊόντα 

Απαντήσεις σε αυτές τις δηλώσεις πολιτικής μπορούν να δοθούν από το χώρο ενός γραφείου (δεν χρειάζεται να εξεταστεί ο χώρος εργασίας).
 

3.4 Προκαθορισμένη εκτίμηση του κινδύνου
----------------------------------------
 
Για κάθε τύπο “κινδύνου”, μπορείτε να επιλέξετε 2 μεθόδους εκτίμησης:

  * **Εκτιμώμενη**: επιλέγοντας **υψηλό, μεσαίο** ή **χαμηλό**. 

  * **Υπολογισμένη**: αξιολογώντας την **πιθανότητα, τη συχνότητα** και τη **σοβαρότητα** ξεχωριστά. Το εργαλείο ΕΚ στη συνέχεια υπολογίζει αυτόματα την προτεραιότητα.

Οι τελικοί χρήστες δεν θα χρειαστεί να αξιολογήσουν τους παρακάτω κινδύνους στο βήμα “Αξιολόγηση”:

  * Οι έκτακτοι κίνδυνοι (θεωρούνται εξ ορισμού "υψηλής προτεραιότητας" και εμφανίζονται με την ένδειξη “Υψηλός” στο σχέδιο δράσης)

  * Πολιτική (δεν αποτελεί κίνδυνο με την αυστηρή έννοια).


3.5 Προτείνετε λύσεις
---------------------

Ο κλάδος είναι γενικά καλά ενημερωμένος για τους κινδύνους που κατά πάσα πιθανότητα μπορούν να οδηγήσουν σε εργατικά ατυχήματα και επαγγελματικές ασθένειες. Για να βοηθήσετε τον τελικό χρήστη να βρει λύσεις για αυτούς τους κινδύνους, μπορείτε να συμπεριλάβετε τις λύσεις που συνιστώνται από τον κλάδο/τους ειδικούς. Ενώ ασχολείται με το σχέδιο δράσης, ο τελικός χρήστης θα έχει τη δυνατότητα να επιλέξει τις λύσεις και να τις επεξεργαστεί εκ νέου (τροποποίηση του κειμένου) σύμφωνα με την κατάσταση που επικρατεί στην επιχείρησή του.

.. note::

  Όλα τα απαραίτητα έγγραφα διατίθενται στον ιστότοπο της κοινότητας το εργαλείου ΕΚ http://www.oiraproject.eu/
